@@ -1,5 +1,7 @@
 package SampleModule;
 
+use strict;
+use warnings;
 use Log::Log4perl qw(:easy);
 
 sub test
